@@ -12,7 +12,6 @@
 #include <MailTransport/TransportManager>
 #include <QQmlEngine>
 #include <QRegularExpression>
-#include <QUrl>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -85,13 +84,13 @@ QString AccountConfiguration::generateUniqueAccountName() const
     QString name;
     switch (mIncomingProtocol) {
     case POP3:
-        name = u"Pop3 (%1)"_s.arg(mIncomingHostName);
+        name = u"POP3 (%1)"_s.arg(mIdentity.primaryEmailAddress());
         break;
     case IMAP:
-        name = u"Imap (%1)"_s.arg(mIncomingHostName);
+        name = u"IMAP (%1)"_s.arg(mIdentity.primaryEmailAddress());
         break;
     case KOLAB:
-        name = u"Kolab (%1)"_s.arg(mIncomingHostName);
+        name = u"Kolab (%1)"_s.arg(mIdentity.primaryEmailAddress());
         break;
     default:
         qCWarning(ACCOUNTWIZARD_LOG) << " invalid protocol: " << mIncomingProtocol;
@@ -163,19 +162,6 @@ Resource::ResourceInfo AccountConfiguration::createKolabResource() const
     auto info = createImapResource();
     info.name = generateUniqueAccountName();
     info.typeIdentifier = u"akonadi_kolab_resource"_s;
-    info.settings = {
-        {u"ImapServer"_s, mIncomingHostName},
-        {u"UserName"_s, mIncomingUserName},
-        {u"DisconnectedModeEnabled"_s, mDisconnectedModeEnabled},
-        {u"Password"_s, mPassword},
-        {u"ImapPort"_s, mIncomingPort},
-        {u"IntervalCheckTime"_s, 60},
-        {u"SubscriptionEnabled"_s, true},
-        {u"UseDefaultIdentity"_s, false},
-        {u"AccountIdentity"_s, mIdentity.uoid()},
-        {u"Authentication"_s, mIncomingAuthenticationProtocol},
-        {u"Safety"_s, mIncomingSecurityProtocol},
-    };
     return info;
 }
 
@@ -283,7 +269,6 @@ void AccountConfiguration::save(ConsoleLog *consoleLog)
 
 void AccountConfiguration::checkServer()
 {
-    qDebug() << " Verify server";
     if (!mServerTest) {
         mServerTest = new ServerTest(this);
         connect(mServerTest, &ServerTest::testFail, this, &AccountConfiguration::slotTestFail);
